Data Structures
======

.. currentmodule:: manim_dsa

.. autosummary::
    :toctree: ../reference_autosummary

    ~m_collection.m_array.MArray
    ~m_collection.m_stack.MStack
    ~m_graph.m_graph.MGraph
